<?php

namespace App\Http\Controllers\addon\committee\admin;

use App\Http\Controllers\Controller;
use App\Models\CommitteeCandidateComment;
use App\Models\CommitteeCategory;
use App\Models\CommitteeElection;
use App\Traits\ResponseTrait;
use Exception;
use Illuminate\Http\Request;

class CandidateCommentController extends Controller
{
    use ResponseTrait;

    public function comments(Request $request)
    {
        if($request->wantsJson()) {

            $candidateComment = CommitteeCandidateComment::join('committee_candidates', 'committee_candidate_comments.committee_candidate_id', '=', 'committee_candidates.id')
                ->join('committee_elections', 'committee_elections.id', '=', 'committee_candidates.committee_election_id')
                ->join('committee_categories', 'committee_categories.id', '=', 'committee_candidates.committee_category_id')
                ->join('committee_designations', 'committee_designations.id', '=', 'committee_candidates.committee_designation_id')
                ->select('committee_designations.name as designation', 'committee_categories.name as category', 'committee_elections.session', 'committee_candidate_comments.*')
                ->with('user')
                ->orderBy('committee_candidate_comments.id', 'DESC');

            if ($request->committee_election_id != 0) {
                $candidateComment->where('committee_elections.id', $request->committee_election_id);
            }
            if ($request->committee_category_id != 0) {
                $candidateComment->where('committee_categories.id', $request->committee_category_id);
            }

            return datatables($candidateComment)
                ->editColumn('status', function ($data) {
                    if ($data->status == STATUS_PENDING) {
                        return '<span class="zBadge">' . __("Unpublished") . '</span>';
                    }

                    return '<span class="zBadge-paid">' . __("Publish") . '</span>';
                })
                ->addColumn('action', function ($data) {
                    return '<ul class="d-flex align-items-center cg-5 justify-content-center">
                            <li class="d-flex gap-2">
                                <button onclick="getEditModal(\'' . route('committee.admin.candidates-comments.status_change_modal', $data->id) . '\'' . ', \'#edit-modal\')" class="d-flex justify-content-center align-items-center w-30 h-30 rounded-circle bd-one bd-c-ededed bg-white" title="' . __('Change Status') . '">
                                    <img src="' . asset('assets/images/icon/edit.svg') . '" alt="Change Status" />
                                </button>
                            </li>
                        </ul>';
                })
                ->rawColumns(['action', 'status'])
                ->make(true);
        }

        $data['title'] = __('Candidate Comments');
        $data['showManageVote'] = 'show';
        $data['activeManageCommitteeCandidateComment'] = 'active';
        $data['elections'] = CommitteeElection::where('tenant_id', getTenantId())->where('status', STATUS_ACTIVE)->get();
        $data['categories'] = CommitteeCategory::where('tenant_id', getTenantId())->where('status', STATUS_ACTIVE)->get();
        return view('addon.committee.admin.candidates.comments.index', $data);
    }

    public function statusChangeModal($id)
    {
        $data['candidateComment'] = CommitteeCandidateComment::where('id', $id)->first();
        return view('addon.committee.admin.candidates.comments.status_modal', $data);
    }

    public function statusChange($id, Request $request)
    {
        try{
            CommitteeCandidateComment::where('id', $id)->update(['status' => $request->status]);
        }catch(Exception $e){
            return $this->error([], getMessage(SOMETHING_WENT_WRONG));
        }
        return $this->success([], getMessage(UPDATED_SUCCESSFULLY));
    }
}
