<?php

namespace App\Http\Controllers\addon\committee\admin;

use App\Http\Controllers\Controller;
use App\Http\Services\addon\committee\CategoryService;
use App\Http\Services\addon\committee\CandidateService;
use App\Http\Services\addon\committee\ElectionService;
use App\Models\CommitteeCandidateFlag;
use App\Models\RegisterForm;
use App\Traits\ResponseTrait;
use Exception;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\DB;

class CandidateController extends Controller
{
    use ResponseTrait;

    public $candidateService;

    public function __construct()
    {
        $this->candidateService = new CandidateService();
    }

    public function pending(Request $request)
    {
        if ($request->wantsJson()) {
            return $this->candidateService->list($request, STATUS_PENDING);
        }
        $committeeElection = new ElectionService();
        $categoryService = new CategoryService();
        $data['title'] = __('Pending Candidate List');
        $data['showManageVote'] = 'show';
        $data['activePendingCandidate'] = 'active';
        $data['elections'] = $committeeElection->getAllActive();
        $data['categories'] = $categoryService->getAllActive();

        return view('addon.committee.admin.candidates.pending', $data);
    }

    public function final(Request $request)
    {
        if ($request->wantsJson()) {
            return $this->candidateService->list($request, STATUS_ACTIVE);
        }
        $committeeElection = new ElectionService();
        $categoryService = new CategoryService();
        $data['title'] = __('Candidate List');
        $data['showManageVote'] = 'show';
        $data['activeFinalCandidate'] = 'active';
        $data['elections'] = $committeeElection->getAllActive();
        $data['categories'] = $categoryService->getAllActive();

        return view('addon.committee.admin.candidates.final', $data);
    }

    public function view($id)
    {
        $data['title'] = __('Candidate View');
        $data['showManageVote'] = 'show';
        $data['activePendingCandidate'] = 'active';
        $data['nomination'] = $this->candidateService->getData($id);
        $data['regForm'] = RegisterForm::where('tenant_id', getTenantId())->first();
        return view('addon.committee.admin.candidates.view', $data);
    }

    public function statusModal(Request $request, $id)
    {
        $data['nomination'] = $this->candidateService->getData($id);
        $data['status'] = $request->status;
        return view('addon.committee.admin.candidates.status_modal', $data);
    }

    public function statusChange(Request $request, $id)
    {
        $request->validate([
            'status' => 'required',
            'reason' => 'required_if:status,2',
        ], [
            'reason.required_if' => __('This field is required')
        ]);

        DB::beginTransaction();
        try {
            $nomination = $this->candidateService->getData($id);
            if ($request->status == STATUS_ACTIVE) {
                $availableFlagIds = CommitteeCandidateFlag::where([
                    'committee_category_id' => $nomination->committee_category_id,
                    'committee_election_id' => $nomination->committee_election_id,
                    'status' => STATUS_ACTIVE
                ])
                    ->whereNotIn('id', function ($query) {
                        $query->select('flag_id')
                            ->from('committee_candidates')
                            ->where('status', 1);
                    })
                    ->select('committee_candidate_flags.id')
                    ->get()
                    ->pluck('id')
                    ->toArray();

                if (count($availableFlagIds) < 1) {
                    DB::rollBack();
                    return $this->error([], __('You dont have available symbol to approve the candidate'));
                } elseif (!$request->random_symbol && !(in_array($nomination->flag_id, $availableFlagIds))) {
                    DB::rollBack();
                    return $this->error([], __('Please select random flag'));
                }

                if ($request->random_symbol) {
                    $randomSymbol = $availableFlagIds[array_rand($availableFlagIds)];
                    $nomination->update([
                        'flag_id' => $randomSymbol,
                        'status' => STATUS_ACTIVE,
                        'approved_by' => auth()->id()
                    ]);
                } else {
                    $nomination->update([
                        'status' => STATUS_ACTIVE,
                        'approved_by' => auth()->id()
                    ]);
                }
            } elseif ($request->status == STATUS_PENDING) {
                $nomination->update([
                    'status' => $request->status
                ]);
            } elseif ($request->status == STATUS_CANCELED) {
                $nomination->update([
                    'status' => $request->status,
                    'reject_reason' => $request->reason,
                    'rejected_by' => auth()->id()
                ]);
            }

            DB::commit();
            return $this->success([], __(UPDATED_SUCCESSFULLY));
        } catch (Exception $e) {
            DB::rollBack();
            return $this->error([], __(SOMETHING_WENT_WRONG));
        }
    }
}
