<?php

namespace App\Http\Controllers\addon\committee\admin;

use App\Http\Controllers\Controller;
use App\Http\Requests\Admin\CommitteeElectionRequest;
use App\Http\Services\addon\committee\ElectionService;
use App\Models\Alumni;
use App\Models\CommitteeCandidate;
use App\Models\CommitteeElection;
use App\Models\CommitteeNominationForm;
use App\Models\CommitteeVote;
use App\Models\User;
use App\Traits\ResponseTrait;
use Illuminate\Http\Request;

class ElectionController extends Controller
{
    use ResponseTrait;
    public $committeeElectionServices;

    public function __construct()
    {
        $this->committeeElectionServices = new ElectionService();
    }

    public function index(Request $request)
    {
        if($request->wantsJson()){
            return $this->committeeElectionServices->list();
        }

        $data['title'] = __('Election List');
        $data['showManageCommittee'] = 'show';
        $data['activeElectionList'] = 'active';

        return view('addon.committee.admin.election.index', $data);
    }


    public function store(CommitteeElectionRequest $request)
    {
        return $this->committeeElectionServices->store($request);
    }

    public function edit($id)
    {
        $data['getElectionData'] = $this->committeeElectionServices->getById($id);

        return view('addon.committee.admin.election.edit-form', $data);
    }

    public function update(CommitteeElectionRequest $request, $id)
    {
        return $this->committeeElectionServices->update( $id, $request);
    }

    public function delete($id)
    {
        return $this->committeeElectionServices->deleteById($id);
    }

    public function resultList(Request $request)
    {
        if($request->wantsJson()){
            return $this->committeeElectionServices->resultList();
        }

        $data['title'] = __('Election List');
        $data['showManageVote'] = 'show';
        $data['activeElectionResultList'] = 'active';

        return view('addon.committee.admin.election.result_list', $data);
    }

    public function result($id)
    {
        $data['title'] = __('Election Result Details');
        $data['showManageVote'] = 'show';
        $data['activeElectionResultList'] = 'active';

        $data['election'] = CommitteeElection::where(['id' => $id, 'tenant_id' => getTenantId()])->first();

        $data['nominations'] = CommitteeNominationForm::where(['tenant_id' => getTenantId(), 'committee_election_id' => $data['election']->id, 'status' => STATUS_ACTIVE])
            ->with(['final_candidates.user.alumni', 'final_candidates.approved_votes', 'position'])
            ->get();

        $data['nominations'] = CommitteeNominationForm::where([
                'tenant_id' => getTenantId(),
                'committee_election_id' => $data['election']->id,
                'status' => STATUS_ACTIVE
            ])
            ->with(['final_candidates.user.alumni', 'position', 'final_candidates' => function ($query) {
                $query->withCount(['approved_votes as vote_count']);
                $query->withCount(['total_votes as total_vote_count']);
            }])
            ->get();

        $data['totalPosition'] = CommitteeNominationForm::where('tenant_id', getTenantId())
            ->where('status', STATUS_ACTIVE)
            ->where('committee_election_id', $data['election']->id)
            ->count();
        $data['totalVoter'] = User::join('alumnus', 'users.id', '=', 'alumnus.user_id')
            ->whereIn('users.role', [USER_ROLE_ALUMNI, USER_ROLE_ADMIN])
            ->where(['users.tenant_id' => getTenantId()])
            ->where('users.status', STATUS_ACTIVE)
            ->count();
        $data['totalVoteCast'] = CommitteeVote::where('tenant_id', getTenantId())
            ->where('committee_election_id', $data['election']->id)
            ->distinct('user_id')
            ->count();
        return view('addon.committee.admin.election.result_details', $data);
    }
}
