<?php

namespace App\Http\Controllers\addon\committee\admin;

use App\Http\Controllers\Controller;
use App\Http\Requests\Admin\CommitteeNominationRequest;
use App\Http\Services\addon\committee\CategoryService;
use App\Http\Services\addon\committee\NominationService;
use App\Http\Services\addon\committee\DesignationService;
use App\Http\Services\addon\committee\ElectionService;
use App\Traits\ResponseTrait;
use Illuminate\Http\Request;

class NominationController extends Controller
{
    use ResponseTrait;
    public $nominationService;

    public function __construct()
    {
        $this->nominationService = new NominationService();
    }

    public function index(Request $request)
    {
        if($request->wantsJson()){
            return $this->nominationService->list($request);
        }
        $committeeDesignation = new DesignationService();
        $committeeElection = new ElectionService();
        $categoryService = new CategoryService();
        $data['title'] = __('Nomination List');
        $data['showManageCommittee'] = 'show';
        $data['activeNominationList'] = 'active';
        $data['designations'] = $committeeDesignation->getAllActive();
        $data['elections'] = $committeeElection->getAllActive();
        $data['categories'] = $categoryService->getAllActive();

        return view('addon.committee.admin.nominations.index', $data);
    }

    public function store(CommitteeNominationRequest $request)
    {
        return $this->nominationService->store($request);
    }

    public function info($id)
    {
        $committeeDesignation = new DesignationService();
        $committeeElection = new ElectionService();
        $categoryService = new CategoryService();
        $data['designations'] = $committeeDesignation->getAllActive();
        $data['elections'] = $committeeElection->getAllActive();
        $data['categories'] = $categoryService->getAllActive();
        $data['nomination'] = $this->nominationService->getById($id);
        return view('addon.committee.admin.nominations.edit-form', $data);
    }

    public function update(CommitteeNominationRequest $request, $id)
    {
        return $this->nominationService->update($request, $id);
    }

    public function delete($id)
    {
        return $this->nominationService->deleteById($id);
    }

    public function transactionList(Request $request)
    {
        if($request->wantsJson()){
            return $this->nominationService->transactionListByStatus($request);
        }

        $data['title'] = __('Nomination Transaction');
        $data['showManageCommittee'] = 'show';
        $data['activeNominationTransaction'] = 'active';

        return view('addon.committee.admin.nominations.transaction', $data);
    }

    public function orderGetInfo(Request $request)
    {
        $data = $this->nominationService->orderGetInfo($request->id);
        return $this->success($data);
    }

    public function orderPaymentStatusChange(Request $request)
    {
        return $this->nominationService->orderPaymentStatusChange($request);
    }
}
