<?php

namespace App\Http\Controllers\addon\committee\alumni;

use App\Http\Controllers\Controller;
use App\Http\Requests\NominationCheckoutRequest;
use App\Http\Services\addon\committee\CandidateFlagService;
use App\Http\Services\addon\committee\CategoryService;
use App\Http\Services\addon\committee\DesignationService;
use App\Http\Services\addon\committee\ElectionService;
use App\Http\Services\addon\committee\NominationService;
use App\Http\Services\Payment\Payment;
use App\Models\Bank;
use App\Models\CommitteeCandidate;
use App\Models\Currency;
use App\Models\FileManager;
use App\Models\Gateway;
use App\Models\GatewayCurrency;
use App\Models\Payment as ModelsPayment;
use App\Traits\ResponseTrait;
use Exception;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\DB;

class NominationController extends Controller
{
    use ResponseTrait;

    public $nominationService;

    public function __construct()
    {
        $this->nominationService = new NominationService();
    }

    public function applyList(Request $request)
    {
        if ($request->wantsJson()) {
            return $this->nominationService->applyList($request);
        }

        $data['title'] = __('Nomination List');
        $data['activeNominationApplyList'] = 'active';
        $data['showManageAluVote'] = 'show';
        $committeeElection = new ElectionService();
        $categoryService = new CategoryService();
        $data['elections'] = $committeeElection->getAllActive();
        $data['categories'] = $categoryService->getAllActive();

        return view('addon.committee.alumni.nominations.apply_list', $data);
    }

    public function apply($id)
    {
        $tenantId = getTenantId();
        $data['title'] = __('Nomination Apply');
        $data['activeNominationApplyList'] = 'active';
        $data['showManageAluVote'] = 'show';

        $data['nomination'] = $this->nominationService->getById($id);

        $committeeDesignation = new DesignationService();
        $committeeElection = new ElectionService();
        $categoryService = new CategoryService();
        $candidateFlagService = new CandidateFlagService();
        $data['designations'] = $committeeDesignation->getAllActive();
        $data['elections'] = $committeeElection->getAllActive();
        $data['categories'] = $categoryService->getAllActive();
        $data['electionFlags'] = $candidateFlagService->getAllActive($data['nomination']->committee_election_id, $data['nomination']->committee_category_id);

        $data['gateways'] = Gateway::where('tenant_id', $tenantId)->where('status', ACTIVE)->get();
        $data['banks'] = Bank::where('tenant_id', $tenantId)->where('status', ACTIVE)->get();
        $candidate = CommitteeCandidate::where('status', '!=', -1)
            ->where('committee_nomination_form_id', $id)
            ->where('user_id' , auth()->id())
            ->first();
        if (!is_null($candidate)) {
            return back()->with('error', __('Already Applied'));
        } else if (is_null($data['nomination']) || $data['nomination']->end_date < now() || $data['nomination']->start_date > now()) {
            return back()->with('error', __('You have selected wrong nomination'));
        }
        return view('addon.committee.alumni.nominations.apply', $data);
    }

    public function checkout(NominationCheckoutRequest $request, $id)
    {
        $nomination = $this->nominationService->getById($id);

        if (is_null($nomination) || $nomination->end_date < now() || $nomination->start_date > now()) {
            return $this->error([], __('You have selected wrong nomination'));
        }

        if (!is_null($nomination->amount) && $nomination->amount > 0) {
            try {
                DB::beginTransaction();
                $gateway = Gateway::where(['slug' => $request->gateway, 'status' => ACTIVE])->where('tenant_id', getTenantId())->first();
                if (is_null($gateway)) {
                    return $this->error([], __('Gateway Not Found'));
                }
                $gatewayCurrency = GatewayCurrency::where(['gateway_id' => $gateway->id, 'id' => $request->currency])->first();
                if (is_null($gatewayCurrency)) {
                    return $this->error([], __('Gateway Currency Not Found'));
                }

                $price = $request->amount;


                if (!isset($nomination)) {
                    return $this->error([], __('Desire Campaign data not found'));
                }

                if (is_null($gatewayCurrency)) {
                    return $this->error([], __('Gateway Currency Not Found'));
                }

                if ($gateway->slug == 'bank') {
                    try {
                        $bank = Bank::where(['gateway_id' => $gateway->id, 'id' => $request->bank_id])->where('tenant_id', getTenantId())->firstOrFail();
                        $bank_id = $bank->id;
                        $deposit_slip_id = null;
                        if ($request->hasFile('bank_slip')) {
                            $new_file = new FileManager();
                            $uploaded = $new_file->upload('payments', $request->bank_slip);
                            $deposit_slip_id = $uploaded->id;
                        }

                        $order = $this->placeOrder($nomination, $price, $gateway, $gatewayCurrency, $bank_id, $deposit_slip_id);
                        $this->nominationFillUp($request, $nomination, 0, $order);
                        DB::commit();
                        return $this->success(['url' => route('committee.alumni.nominations.apply_list')], __('Bank Details Sent Successfully! Wait for approval'));
                    } catch (\Exception $e) {
                        DB::rollBack();
                        return $this->success([], __('Your application has been failed!'));
                    }
                } else {
                    $order = $this->placeOrder($nomination, $price, $gateway, $gatewayCurrency); // new order create
                    $this->nominationFillUp($request, $nomination, -1, $order);
                }

                $object = [
                    'id' => $order->id,
                    'callback_url' => route('nomination_apply.verify'),
                    'currency' => $gatewayCurrency->currency
                ];

                $payment = new Payment($gateway->slug, $object);
                $responseData = $payment->makePayment($order->grand_total);

                DB::commit();
                if ($responseData['success']) {
                    $order->paymentId = $responseData['payment_id'];
                    $order->save();
                    return $this->success(['url' => $responseData['redirect_url']], __('Payment link created'));
                } else {
                    return $this->error([], __(SOMETHING_WENT_WRONG));
                }
            } catch (Exception $e) {
                DB::rollBack();
                return $this->error([], __(SOMETHING_WENT_WRONG));
            }
        } else {
            try {
                DB::beginTransaction();
                $this->nominationFillUp($request, $nomination, 0);
                DB::commit();
                return $this->success(['url' => route('committee.alumni.nominations.apply_list')], __('Successfully Applied'));
            }catch (Exception $e){
                DB::rollBack();
                return $this->error([], __(SOMETHING_WENT_WRONG));
            }
        }
    }

    public function verify(Request $request)
    {
        $order_id = $request->get('id', '');
        $payerId = $request->get('PayerID', NULL);
        $payment_id = $request->get('payment_id', NULL);

        $order = ModelsPayment::find($order_id);
        if (is_null($order)) {
            return redirect()->route('checkout.success', ['success' => 0, 'message' => __('Your payment is not exist!')]);
        }

        if ($order->payment_status == PAYMENT_STATUS_PAID) {
            return redirect()->route('checkout.success', ['success' => 0, 'message' => __('Your payment is not exist!')]);
        }

        $gateway = Gateway::find($order->gateway_id);
        DB::beginTransaction();
        try {
            if ($order->gateway_id == $gateway->id && $gateway->slug == MERCADOPAGO) {
                $order->paymentId = $payment_id;
                $order->save();
            }

            $payment_id = $order->paymentId;

            $gatewayBasePayment = new Payment($gateway->slug, ['currency' => $order->payment_currency]);
            $payment_data = $gatewayBasePayment->paymentConfirmation($payment_id, $payerId);

            if ($payment_data['success']) {
                if ($payment_data['data']['payment_status'] == 'success') {
                    $order->payment_status = PAYMENT_STATUS_PAID;
                    $order->payment_time = now();
                    $order->gateway_callback_details = json_encode($request->all());
                    $order->save();

                    $candidate = CommitteeCandidate::where('payment_id', $order->id)->where('status', -1)->first();
                    $candidate->update(['status' => STATUS_PENDING]);

                    $purpose = __('Nomination Payment Completed for ') . $order->paymentable->title;
                    $type = TRANSACTION_NOMINATION;

                    //Create Transaction
                    $order->transaction()->create([
                        'user_id' => $order->user_id,
                        'tenant_id' => getTenantId(),
                        'reference_id' => $candidate->id,
                        'type' => $type,
                        'tnxId' => $order->tnxId,
                        'amount' => $order->grand_total,
                        'purpose' => $purpose,
                        'payment_time' => $order->payment_time,
                        'payment_method' => $gateway->title
                    ]);

                    setCommonNotification(__('Payment'), $purpose, route('transaction.list'), $order->user_id);
                    $customData = [
                        'transaction_no' => $order->tnxId,
                    ];
                    $link = route('transaction.list');
                    genericEmailNotify('', $order->user, $customData, 'payment-success', $link);

                    DB::commit();
                    return redirect()->route('checkout.success', ['success' => 1, 'message' => __('Your payment has been successful!')]);
                }
            }

            return redirect()->route('checkout.success', ['success' => 0, 'message' => __('Your payment has been failed!')]);
        } catch (\Exception $e) {
            DB::rollBack();
            return redirect()->route('checkout.success', ['success' => 0, 'message' => __('Your payment has been failed')]);
        }
    }

    public function placeOrder($object, $price, $gateway, $gatewayCurrency, $bank_id = null, $deposit_slip_id = null)
    {
        $payment = $object->payments()->create([
            'user_id' => auth()->id(),
            'tnxId' => uniqid(),
            'tenant_id' => getTenantId(),
            'amount' => $price,
            'system_currency' => Currency::where('current_currency', 'on')->first()->currency_code,
            'gateway_id' => $gateway->id,
            'payment_currency' => $gatewayCurrency->currency,
            'conversion_rate' => $gatewayCurrency->conversion_rate,
            'sub_total' => $price,
            'grand_total' => $price,
            'grand_total_with_conversation_rate' => $price * $gatewayCurrency->conversion_rate,
            'bank_id' => $bank_id,
            'deposit_slip' => $deposit_slip_id,
            'payment_details' => json_encode($object),
            'payment_status' => PAYMENT_STATUS_PENDING
        ]);

        return $payment;
    }

    public function nominationFillUp($request, $nomination, $status, $payment = NULL)
    {
        $customFields = json_decode($request->custom_fields);
        $new_file = new FileManager();
        foreach ($request->allFiles() as $key => $value) {
            $uploaded = $new_file->upload('nominations', $value);
            $userData = $uploaded->id;
            if(!empty($customFields)){
                $index = array_search($key, array_column($customFields, 'name'));
                $customFields[$index]->userData = [$userData];
            }
        }

        $photo = auth()->user()->image;
        if ($request->hasFile('photo')) {
            $uploaded = $new_file->upload('nominations', $request->photo);
            $photo = $uploaded->id;
        }

        CommitteeCandidate::create([
            'user_id' => auth()->id(),
            'committee_election_id' => $nomination->committee_election_id,
            'committee_designation_id' => $nomination->committee_designation_id,
            'committee_category_id' => $nomination->committee_category_id,
            'committee_nomination_form_id' => $nomination->id,
            'photo' => $photo,
            'payment_id' => $payment?->id,
            'tenant_id' => getTenantId(),
            'election_manifesto' => $request->election_manifesto,
            'flag_id' => $request->symbol_id,
            'form_data' => json_encode($customFields),
            'status' => $status ?? -1,
        ]);
    }

}
