<?php

namespace App\Http\Services\addon\committee;

use App\Models\CommitteeBoardMember;
use App\Models\FileManager;
use App\Models\User;
use App\Traits\ResponseTrait;
use Exception;
use Illuminate\Support\Facades\DB;

class BoardMemberService
{
    use ResponseTrait;

    public function list($request)
    {
        $boardMember = CommitteeBoardMember::where('committee_board_members.tenant_id', getTenantId())
            ->join('committee_designations', 'committee_designations.id' , '=', 'committee_board_members.committee_designation_id')
            ->join('committee_elections', 'committee_elections.id' , '=', 'committee_board_members.committee_election_id')
            ->with('user')
            ->select('committee_designations.name as designation', 'committee_designations.order', 'committee_elections.session', 'committee_board_members.*')
            ->orderBy('committee_elections.id', 'DESC')
            ->orderBy('committee_designations.order', 'ASC');

        if($request->committee_election_id != 0){
            $boardMember->where('committee_elections.id', $request->committee_election_id);
        }

        return datatables($boardMember)
            ->editColumn('photo', function ($data) {
                if(!is_null($data->photo)){
                    return '<img class="avatar-xs max-h-35 max-h-69 rounded" src="'.getFileUrl($data->photo) .'"/>';
                }

                return '<img class="avatar-xs max-h-35 max-h-69 rounded" src="'.getFileUrl($data->user->image) .'"/>';
            })

            ->editColumn('status', function ($data) {
                if($data->status == STATUS_DEACTIVATE) {
                    return '<span class="zBadge-free">'.__("Deactivated").'</span>';
                }

                return '<span class="zBadge-one">'.__("Active").'</span>';
            })
            ->addColumn('action', function ($data) {
                return '<ul class="d-flex align-items-center cg-5 justify-content-center">
                            <li class="d-flex gap-2">
                                <button onclick="getEditModal(\'' . route('committee.admin.board_members.info', [$data->id]) . '\'' . ', \'#edit-modal\')" class="d-flex justify-content-center align-items-center w-30 h-30 rounded-circle bd-one bd-c-ededed bg-white" title="' . __('Edit') . '">
                                    <img src="' . asset('assets/images/icon/edit.svg') . '" alt="edit" />
                                </button>
                                <button onclick="deleteItem(\'' . route('committee.admin.board_members.delete', [$data->id]) . '\', \'boardMemberDatatable\')" class="d-flex justify-content-center align-items-center w-30 h-30 rounded-circle bd-one bd-c-ededed bg-white" title="' . __('Delete') . '">
                                    <img src="' . asset('assets/images/icon/delete-1.svg') . '" alt="delete">
                                </button>
                            </li>
                        </ul>';
            })
            ->rawColumns(['action', 'photo', 'status'])
            ->make(true);
    }

    public function store($request)
    {
        DB::beginTransaction();
        try {

            $photo = NULL;

            if ($request->hasFile('photo')) {
                $new_file = new FileManager();
                $uploaded = $new_file->upload('election', $request->photo);
                $photo = $uploaded->id;
            }

            $user = User::create([
                'name' => $request->name,
                'email' => $request->email,
                'mobile' => $request->phone,
                'password' => bcrypt($request->password),
                'image' => $photo,
                'role' => USER_ROLE_BOARD_MEMBER,
                'tenant_id' => getTenantId(),
            ]);

            $createData = [
                'tenant_id' => getTenantId(),
                'committee_election_id' => $request->election_id,
                'user_id' => $user->id,
                'committee_designation_id' => $request->designation_id,
                'photo' => $photo,
                'company' => $request->company,
                'address' => $request->address,
                'created_by' => auth()->id(),
                'status' => $request->status,
            ];

            CommitteeBoardMember::create($createData);
            DB::commit();
            return $this->success([], getMessage(CREATED_SUCCESSFULLY));
        } catch (Exception $e) {
            DB::rollBack();
            return $this->error([], getMessage(SOMETHING_WENT_WRONG));
        }
    }

    public function update($request, $id)
    {
        DB::beginTransaction();
        try {
            $boardMember = CommitteeBoardMember::where('id', $id)->with('user')->first();
            $photo = $boardMember->photo;
            $password = $boardMember->password;

            if ($request->hasFile('photo')) {
                $new_file = new FileManager();
                $uploaded = $new_file->upload('election', $request->photo);
                $photo = $uploaded->id;
            }
            if($request->password){
                $password = bcrypt($request->password);
            }

            $boardMember->user->update([
                'name' => $request->name,
                'email' => $request->email,
                'mobile' => $request->phone,
                'password' => $password,
                'image' => $photo,
            ]);

            $updateData = [
                'committee_election_id' => $request->election_id,
                'user_id' => $boardMember->user_id,
                'committee_designation_id' => $request->designation_id,
                'photo' => $photo,
                'company' => $request->company,
                'address' => $request->address,
                'status' => $request->status,
            ];

            $boardMember->update($updateData);
            DB::commit();
            return $this->success([], getMessage(UPDATED_SUCCESSFULLY));
        } catch (Exception $e) {
            DB::rollBack();
            return $this->error([], getMessage(SOMETHING_WENT_WRONG));
        }
    }

    public function getById($id)
    {
        return CommitteeBoardMember::where('tenant_id', getTenantId())->where(['id' => $id])->first();
    }

    public function deleteById($id)
    {
        DB::beginTransaction();
        try {
            $boardMember = $this->getById($id);
            $boardMember->user->update(['status', STATUS_DEACTIVATE]);
            $boardMember->delete();
            DB::commit();
            $message = getMessage(DELETED_SUCCESSFULLY);
            return $this->success([], $message);
        } catch (\Exception $e) {
            DB::rollBack();
            $message = getErrorMessage($e, $e->getMessage());
            return $this->error([], $message);
        }
    }
}
