<?php

namespace App\Http\Services\addon\committee;

use App\Models\CommitteeCategory;
use App\Models\User;
use App\Traits\ResponseTrait;
use Exception;
use Illuminate\Support\Facades\DB;

class CategoryService
{
    use ResponseTrait;

    public function list()
    {
        $committeeCategory = CommitteeCategory::query()->where('tenant_id', getTenantId())->orderBy('id','DESC');
        return datatables($committeeCategory)
            ->addIndexColumn()
            ->addColumn('campaigns',function ($data){
                return $data->campaigns_count ?? 0;
            })
            ->editColumn('showing_home_page' , function ($data){
                if ($data->showing_home_page == STATUS_ACTIVE) {
                    return '<p class="d-inline-block py-6 px-10 bd-ra-6 fs-14 fw-500 lh-16 text-0fa958 bg-0fa958-10">'.__('Yes').'</p>';
                } else {
                    return '<p class="d-inline-block py-6 px-10 bd-ra-6 fs-14 fw-500 lh-16 text-f5b40a bg-f5b40a-10">'.__('No').'</p>';
                }
            })
            ->editColumn('status' , function ($data){
                if ($data->status == STATUS_ACTIVE) {
                    return '<p class="d-inline-block py-6 px-10 bd-ra-6 fs-14 fw-500 lh-16 text-0fa958 bg-0fa958-10">'.__('Active').'</p>';
                } else {
                    return '<p class="d-inline-block py-6 px-10 bd-ra-6 fs-14 fw-500 lh-16 text-f5b40a bg-f5b40a-10">'.__('Deactivate').'</p>';
                }
            })
            ->addColumn('action', function ($data){
                return '<ul class="d-flex align-items-center cg-5 justify-content-center">
                            <li class="d-flex gap-2">
                                <button onclick="getEditModal(\'' . route('committee.admin.categories.edit', $data->id) . '\'' . ', \'#committee-category-edit-modal\')" class="d-flex justify-content-center align-items-center w-30 h-30 rounded-circle bd-one bd-c-ededed bg-white" data-bs-toggle="modal" data-bs-target="#alumniPhoneNo" title="'.__('Edit').'">
                                    <img src="' . asset('assets/images/icon/edit.svg') . '" alt="edit" />
                                </button>
                                <button onclick="deleteItem(\'' . route('committee.admin.categories.delete', $data->id) . '\', \'committeeCategoriesDatatable\')" class="d-flex justify-content-center align-items-center w-30 h-30 rounded-circle bd-one bd-c-ededed bg-white" title="'.__('Delete').'">
                                    <img src="' . asset('assets/images/icon/delete-1.svg') . '" alt="delete">
                                </button>
                            </li>
                        </ul>';
            })
            ->rawColumns(['action', 'status','showing_home_page'])
            ->make(true);
    }


    public function store($request)
    {
        DB::beginTransaction();
        try {

            $committeeCategory = New CommitteeCategory();

            $slug = getSlug($request->name);

            if (CommitteeCategory::where('slug', $slug)->count() > 0) {
                $slug = $slug . '-' . rand(100000, 999999);
            }
            $committeeCategory->tenant_id = getTenantId();
            $committeeCategory->name = $request->name;
            $committeeCategory->slug = $slug;
            $committeeCategory->showing_home_page = $request->showing_home_page;
            $committeeCategory->status = $request->status;

            $committeeCategory->save();
            DB::commit();
            return $this->success([], getMessage(CREATED_SUCCESSFULLY));
        } catch (Exception $e) {
            DB::rollBack();
            return $this->error([], getMessage(SOMETHING_WENT_WRONG));
        }
    }

    public function update($id, $request)
    {
        DB::beginTransaction();
        try {
            $committeeCategory = CommitteeCategory::findOrfail($id);

            $newSlug = getSlug($request->name);

            if (CommitteeCategory::where('slug', $newSlug)->where('tenant_id', getTenantId())->where('id', '!=', $id)->withTrashed()->count() > 0) {
                $newSlug = $newSlug . '-' . rand(100000, 999999);
            }

            $committeeCategory->name = $request->name;
            $committeeCategory->slug = $newSlug;
            $committeeCategory->showing_home_page = $request->showing_home_page;
            $committeeCategory->status = $request->status;

            $committeeCategory->save();
            DB::commit();
            $message = getMessage(UPDATED_SUCCESSFULLY);
            return $this->success([], $message);
        } catch (Exception $e) {
            DB::rollBack();
            $message = getErrorMessage($e, $e->getMessage());
            return $this->error([], $message);
        }
    }

    public function getById($id)
    {
        return CommitteeCategory::where('tenant_id', getTenantId())->findOrfail($id);
    }

    public function getAllActive()
    {
        return CommitteeCategory::where('tenant_id', getTenantId())->where('status', STATUS_ACTIVE)->get();
    }

    public function getUserData(){

        return User::where('tenant_id' , getTenantId())->where('status', STATUS_ACTIVE)->where('role',USER_ROLE_ALUMNI)->get();
    }

    public function deleteById($id)
    {
        DB::beginTransaction();
        try {
            $committeeCategory = CommitteeCategory::FindOrFail($id);

            $committeeCategory->delete();
            DB::commit();
            $message = getMessage(DELETED_SUCCESSFULLY);
            return $this->success([], $message);
        } catch (\Exception $e) {
            DB::rollBack();
            $message = getErrorMessage($e, $e->getMessage());
            return $this->error([], $message);
        }
    }
}
