<?php

namespace App\Http\Services\addon\committee;

use App\Models\CommitteeCandidate;
use App\Models\CommitteeNominationForm;
use App\Models\Gateway;
use App\Models\Payment;
use App\Models\UserPackage;
use App\Traits\ResponseTrait;
use Exception;
use Illuminate\Support\Facades\DB;

class NominationService
{
    use ResponseTrait;

    public function list($request)
    {
        $nomination = CommitteeNominationForm::where('committee_nomination_forms.tenant_id', getTenantId())
            ->join('committee_designations', 'committee_designations.id', '=', 'committee_nomination_forms.committee_designation_id')
            ->join('committee_elections', 'committee_elections.id', '=', 'committee_nomination_forms.committee_election_id')
            ->join('committee_categories', 'committee_categories.id', '=', 'committee_nomination_forms.committee_category_id')
            ->select('committee_designations.name as designation', 'committee_categories.name as category', 'committee_designations.order', 'committee_elections.session', 'committee_nomination_forms.*')
            ->orderBy('committee_elections.id', 'DESC')
            ->orderBy('committee_designations.order', 'ASC');

        if($request->committee_election_id != 0){
            $nomination->where('committee_elections.id', $request->committee_election_id);
        }
        if($request->committee_category_id != 0){
            $nomination->where('committee_categories.id', $request->committee_category_id);
        }

        return datatables($nomination)
            ->editColumn('status', function ($data) {
                $now = now();
                if ($data->status == STATUS_DEACTIVATE) {
                    return '<span class="zBadge">' . __("Deactivated") . '</span>';
                }elseif ($data->start_date > $now) {
                    return '<span class="zBadge-one">' . __("Upcoming") . '</span>';
                }elseif ($data->end_date >= $now) {
                    return '<span class="zBadge-paid">' . __("Running") . '</span>';
                }

                return '<span class="zBadge-free">' . __("Expired") . '</span>';
            })
            ->editColumn('amount', function ($data) {
                if(!is_null($data->amount) && $data->amount > 0){
                    return showPrice($data->amount);
                }
                return __('N/A');
            })
            ->addColumn('action', function ($data) {
                return '<ul class="d-flex align-items-center cg-5 justify-content-center">
                            <li class="d-flex gap-2">
                                <button onclick="getEditModal(\'' . route('committee.admin.nominations.info', [$data->id]) . '\'' . ', \'#edit-modal\', \'editModalResponse\')" class="d-flex justify-content-center align-items-center w-30 h-30 rounded-circle bd-one bd-c-ededed bg-white" title="' . __('Edit') . '">
                                    <img src="' . asset('assets/images/icon/edit.svg') . '" alt="edit" />
                                </button>
                                <button onclick="deleteItem(\'' . route('committee.admin.nominations.delete', [$data->id]) . '\', \'nominationDatatable\')" class="d-flex justify-content-center align-items-center w-30 h-30 rounded-circle bd-one bd-c-ededed bg-white" title="' . __('Delete') . '">
                                    <img src="' . asset('assets/images/icon/delete-1.svg') . '" alt="delete">
                                </button>
                            </li>
                        </ul>';
            })
            ->rawColumns(['action', 'status'])
            ->make(true);
    }

    public function applyList($request)
    {
        $nomination = CommitteeNominationForm::where('committee_nomination_forms.tenant_id', getTenantId())
            ->join('committee_designations', 'committee_designations.id', '=', 'committee_nomination_forms.committee_designation_id')
            ->join('committee_elections', 'committee_elections.id', '=', 'committee_nomination_forms.committee_election_id')
            ->join('committee_categories', 'committee_categories.id', '=', 'committee_nomination_forms.committee_category_id')
            ->where('committee_nomination_forms.status', STATUS_ACTIVE)
            ->where('committee_nomination_forms.end_date', '>=', now())
            ->select('committee_designations.name as designation', 'committee_categories.name as category', 'committee_designations.order', 'committee_elections.session', 'committee_nomination_forms.*')
            ->orderBy('committee_elections.id', 'DESC')
            ->orderBy('committee_designations.order', 'ASC');

        if($request->committee_election_id != 0){
            $nomination->where('committee_elections.id', $request->committee_election_id);
        }
        if($request->committee_category_id != 0){
            $nomination->where('committee_categories.id', $request->committee_category_id);
        }

        return datatables($nomination)
            ->editColumn('status', function ($data) {
                $now = now();
                if ($data->start_date > $now) {
                    return '<span class="zBadge-one">' . __("Upcoming") . '</span>';
                }

                return '<span class="zBadge-paid">' . __("Running") . '</span>';

            })
            ->editColumn('amount', function ($data) {
                if(!is_null($data->amount) && $data->amount > 0){
                    return showPrice($data->amount);
                }
                return __('N/A');
            })
            ->addColumn('action', function ($data) {
                return '<ul class="d-flex align-items-center cg-5 justify-content-center" xmlns="http://www.w3.org/1999/html">
                            <li class="d-flex gap-2">
                                <a href="'.route('committee.alumni.nominations.apply', $data->id).'" class="d-flex justify-content-center align-items-center w-30 h-30 rounded-circle bd-one bd-c-ededed bg-white" title="' . __('Apply') . '">
                                    <i class="fa-solid fa-long-arrow-right" /></i>
                                </a>
                            </li>
                        </ul>';
            })
            ->rawColumns(['action', 'status'])
            ->make(true);
    }

    public function store($request)
    {
        DB::beginTransaction();
        try {

            $createData = [
                'tenant_id' => getTenantId(),
                'committee_election_id' => $request->election_id,
                'committee_category_id' => $request->category_id,
                'committee_designation_id' => $request->designation_id,
                'title' => $request->title,
                'start_date' => $request->start_date,
                'end_date' => $request->end_date,
                'created_by' => auth()->id(),
                'form' => json_encode($request->custom_fields),
                'description' => $request->details,
                'amount' => (!is_null($request->form_price) && $request->form_price > 0) ? $request->form_price : null,
                'status' => $request->status,
            ];

            CommitteeNominationForm::create($createData);
            DB::commit();
            return $this->success([], getMessage(CREATED_SUCCESSFULLY));
        } catch (Exception $e) {
            DB::rollBack();
            return $this->error([], getMessage(SOMETHING_WENT_WRONG));
        }
    }

    public function update($request, $id)
    {
        DB::beginTransaction();
        try {
            $nomination = CommitteeNominationForm::where('id', $id)->first();
            $updateData = [
                'committee_election_id' => $request->election_id,
                'committee_category_id' => $request->category_id,
                'committee_designation_id' => $request->designation_id,
                'start_date' => $request->start_date,
                'title' => $request->title,
                'end_date' => $request->end_date,
                'form' => json_encode($request->custom_fields),
                'description' => $request->details,
                'amount' => (!is_null($request->form_price) && $request->form_price > 0) ? $request->form_price : null,
                'status' => $request->status,
            ];

            $nomination->update($updateData);
            DB::commit();
            return $this->success([], getMessage(UPDATED_SUCCESSFULLY));
        } catch (Exception $e) {
            DB::rollBack();
            return $this->error([], getMessage(SOMETHING_WENT_WRONG));
        }
    }

    public function getById($id)
    {
        return CommitteeNominationForm::where('tenant_id', getTenantId())->where(['id' => $id])->first();
    }

    public function deleteById($id)
    {
        DB::beginTransaction();
        try {
            $nomination = $this->getById($id);
            $nomination->delete();
            DB::commit();
            $message = getMessage(DELETED_SUCCESSFULLY);
            return $this->success([], $message);
        } catch (\Exception $e) {
            DB::rollBack();
            $message = getErrorMessage($e, $e->getMessage());
            return $this->error([], $message);
        }
    }


    public function transactionListByStatus($request)
    {
        $status = 0;
        if ($request->status == 'Approved') {
            $status = PAYMENT_STATUS_PAID;
        } else if ($request->status == 'Pending') {
            $status = PAYMENT_STATUS_PENDING;
        }  else if ($request->status == 'Cancelled') {
            $status = PAYMENT_STATUS_CANCELLED;
        }


        $nominationCandidate = CommitteeCandidate::where('committee_candidates.tenant_id', getTenantId())
            ->join('users', 'users.id', '=', 'committee_candidates.user_id')
            ->join('payments', 'payments.id', '=', 'committee_candidates.payment_id')
            ->join('gateways', 'gateways.id', '=', 'payments.gateway_id')
            ->join('committee_designations', 'committee_designations.id', '=', 'committee_candidates.committee_designation_id')
            ->join('committee_elections', 'committee_elections.id', '=', 'committee_candidates.committee_election_id')
            ->join('committee_categories', 'committee_categories.id', '=', 'committee_candidates.committee_category_id')
            ->leftJoin('banks', 'payments.bank_id', '=', 'banks.id')
            ->select(
                'users.name as userName',
                'users.email as userEmail',
                'gateways.title as gatewayName',
                'gateways.slug as gatewaySlug',
                'banks.name as bankName',
                'committee_designations.name as designation',
                'committee_categories.name as category',
                'committee_elections.session',
                'payments.*'
            )
            ->where(function ($query) {
                $query->where('gateways.slug', '!=', 'bank')
                    ->whereIn('payments.payment_status', [STATUS_ACTIVE, STATUS_REJECT])
                    ->orWhere(function ($query) {
                        $query->where('gateways.slug', '=', 'bank');
                    });
            })
            ->orderBy('payments.id', 'DESC');

        if ($request->status == 'Pending') {
            $nominationCandidate = $nominationCandidate->where('gateways.slug','bank');
        }

        if($request->status != 'All') {
            $nominationCandidate = $nominationCandidate->where('payments.payment_status', $status);
        }

        return datatables($nominationCandidate)
            ->editColumn('status', function ($data) {
                if ($data->payment_status == PAYMENT_STATUS_PAID) {
                    return '<div class="d-inline-block py-6 px-10 bd-ra-6 fs-14 fw-500 lh-16 text-0fa958 bg-0fa958-10">'.__('Paid').'</div>';
                } elseif ($data->payment_status == PAYMENT_STATUS_PENDING) {
                    return '<div class="d-inline-block py-6 px-10 bd-ra-6 fs-14 fw-500 lh-16 text-f5b40a bg-f5b40a-10">'.__('Pending').'</div>';
                } else {
                    return '<div class="d-inline-block py-6 px-10 bd-ra-6 fs-14 fw-500 lh-16 text-ea4335 bg-ea4335-10">'.__('Cancelled').'</div>';
                }
            })
            ->editColumn('amount', function ($data) {
                return showPrice($data->sub_total);
            })
            ->addColumn('payment_info', function ($data) {
                if($data->gatewaySlug == 'bank') {
                    return '<div class="text-nowrap">' .
                        __('TnxId') . ' : ' . $data->tnxId . '<br>' .
                        __('Bank Name') . ' : ' . $data->bankName . '<br>' .
                        __('Deposit Slip') . ' : ' . '<a href="' . (getFileUrl($data->deposit_slip)) . '" target="_blank">' . __('View slip') . '</a>' .
                        '</div>';
                }

                return '<div class="text-nowrap">' .
                    __('TnxId') . ' : ' . $data->tnxId . '<br>' .
                    __('Gateway') . ' : ' . $data->gatewayName . '<br>' .
                    '</div>';
            })
            ->addColumn('nomination', function ($data) {
                return '<div class="text-nowrap">' .
                    __('Election').' : ' . $data->session . '<br>' .
                    __('Committee').' : ' . $data->category . '<br>' .
                    __('Position').' : ' . $data->designation . '<br>' .
                    '</div>';
            })
            ->addColumn('user', function ($data) {
                return '<div class="text-nowrap">' .
                    __('Name').' : ' . $data->userName . '<br>' .
                    __('Email').' : ' . $data->userEmail . '<br>'.
                    '</div>';
            })
            ->addColumn('action', function ($data) {
                $html = '<div class="d-flex justify-content-center align-items-center g-10">';
                $html .= "<button type='button' class='border-0 p-0 bg-transparent flex-shrink-0 me-2 orderPayStatus' title='Status' data-id='$data->id'><img src='" . asset('assets/images/icon/edit.svg') . "'></button>";
                return $html;
            })
            ->rawColumns(['action', 'status', 'user', 'nomination', 'payment_info'])
            ->make(true);
    }

    public function orderGetInfo($id)
    {
        try {
            return Payment::query()
                ->join('gateways', 'payments.gateway_id', '=', 'gateways.id')
                ->select(['payments.*', 'gateways.title as gatewayTitle'])
                ->where('payments.id', $id)
                ->first();
        } catch (Exception $e) {
            $message = getErrorMessage($e, $e->getMessage());
            return $this->error([],  $message);
        }
    }

    public function orderPaymentStatusChange($request)
    {
        DB::beginTransaction();
        try {
            $order=Payment::findOrFail($request->id);

            $order->update([
                'payment_status' => $request->payment_status
            ]);

            if($request->payment_status == PAYMENT_STATUS_PAID) {
                $gateway = Gateway::find($order->gateway_id);
                $order->payment_time = now();
                $order->gateway_callback_details = json_encode($request->all());
                $order->save();

                $candidate = CommitteeCandidate::where('payment_id', $order->id)->where('status', 0)->first();

                $purpose = __('Nomination Payment Completed for ') . $order->paymentable->title;
                $type = TRANSACTION_NOMINATION;

                //Create Transaction
                $order->transaction()->create([
                    'user_id' => $order->user_id,
                    'tenant_id' => getTenantId(),
                    'reference_id' => $candidate->id,
                    'type' => $type,
                    'tnxId' => $order->tnxId,
                    'amount' => $order->grand_total,
                    'purpose' => $purpose,
                    'payment_time' => $order->payment_time,
                    'payment_method' => $gateway->title
                ]);

                setCommonNotification(__('Payment'), $purpose, route('transaction.list'), $order->user_id);
                $customData = [
                    'transaction_no' => $order->tnxId,
                ];
                $link = route('transaction.list');
                genericEmailNotify('', $order->user, $customData, 'payment-success', $link);

            }elseif($request->payment_status == PAYMENT_STATUS_CANCELLED){
                CommitteeCandidate::where('payment_id', $order->id)->update(['status' => STATUS_CANCELED]);
            }

            DB::commit();
            $message = __("Payment Status Changed Successfully.");
            return $this->success([], $message);
        } catch (\Exception $e) {
            DB::rollBack();
            $message = getErrorMessage($e, $e->getMessage());
            return $this->error([], $message);
        }
    }


}
