<?php

namespace App\Http\Controllers\addon\committee\admin;

use App\Http\Controllers\Controller;
use App\Http\Services\addon\committee\CategoryService;
use App\Http\Services\addon\committee\DesignationService;
use App\Http\Services\addon\committee\ElectionService;
use App\Http\Services\addon\committee\VoteService;
use App\Models\Committee;
use App\Models\CommitteeCandidate;
use App\Models\CommitteeElection;
use App\Models\CommitteeVote;
use App\Models\User;
use App\Traits\ResponseTrait;
use Exception;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\DB;

class VoteController extends Controller
{
    use ResponseTrait;

    public $voteService;

    public function __construct()
    {
        $this->voteService = new VoteService();
    }

    public function voteList(Request $request)
    {
        if ($request->wantsJson()) {
            return $this->voteService->voteList($request);
        }

        $data['title'] = __('Vote List');
        $data['showManageVote'] = 'show';
        $data['activeVoteList'] = 'active';
        $committeeDesignation = new DesignationService();
        $committeeElection = new ElectionService();
        $committeeCategory = new CategoryService();
        $data['designations'] = $committeeDesignation->getAllActive();
        $data['elections'] = $committeeElection->getAllActive();
        $data['categories'] = $committeeCategory->getAllActive();

        return view('addon.committee.admin.votes.index', $data);
    }

    public function statusChange(Request $request)
    {
        try {
            CommitteeVote::where('tenant_id', getTenantId())->where('id', $request->id)->update([
                'status' => $request->status
            ]);
            return $this->success([], __(UPDATED_SUCCESSFULLY));
        } catch (Exception $e) {
            return $this->error([], __(SOMETHING_WENT_WRONG));
        }
    }

    public function submitResult(Request $request, $id)
    {
        $election = CommitteeElection::where('id', $id)->first();
        if($election->is_result_done){
            return $this->error([], __('Already published'));
        }
        try {
            DB::beginTransaction();
            $candidates = CommitteeCandidate::where(['tenant_id' => getTenantId(), 'committee_election_id' => $id])
                ->whereIn('id', array_values($request->candidate_id))
                ->get();

            CommitteeCandidate::where(['tenant_id' => getTenantId(), 'committee_election_id' => $id])
                ->whereIn('id', array_values($request->candidate_id))
                ->update(['is_win' => STATUS_ACTIVE]);

            foreach ($candidates as $candidate){
                $photo = $candidate->photo;

                $userData = User::join('alumnus','alumnus.user_id','users.id')
                    ->select(
                        'alumnus.company as alumnusCompanyName',
                        'alumnus.company_address as alumnusCompanyAddress'
                    )
                    ->where('users.tenant_id',getTenantId())
                    ->where('users.id',$candidate->user_id)
                    ->where('alumnus.user_id',$candidate->user_id)->first();

                $createData = [
                    'tenant_id' => getTenantId(),
                    'committee_election_id' => $candidate->committee_election_id,
                    'committee_category_id' => $candidate->committee_category_id,
                    'user_id' => $candidate->user_id,
                    'committee_designation_id' => $candidate->committee_designation_id,
                    'photo' => $photo,
                    'company' => $userData->alumnusCompanyName,
                    'address' => $userData->alumnusCompanyAddress,
                    'created_by' => auth()->id(),
                    'status' => STATUS_ACTIVE,
                ];

                Committee::create($createData);
            }

            $election->update(['is_result_done' => STATUS_ACTIVE]);

            DB::commit();
            return $this->success(['url' => route('committee.admin.votes.index')], __(UPDATED_SUCCESSFULLY));
        } catch (Exception $e) {
            DB::rollBack();
            return $this->error([], __(SOMETHING_WENT_WRONG));
        }
    }
}
