<?php

namespace App\Http\Controllers\addon\committee\frontend;

use App\Http\Controllers\Controller;
use App\Models\CommitteeCandidate;
use App\Models\CommitteeCandidateComment;
use App\Models\CommitteeElection;
use App\Traits\ResponseTrait;
use Illuminate\Http\Request;
use Exception;

class CandidateController extends Controller
{
    use ResponseTrait;

    public function index()
    {
        $data['title'] = __("Candidate");
        $data['designationData'] = CommitteeElection::where(['status' => STATUS_ACTIVE , 'tenant_id' => getTenantId()])->orderBy('id', 'DESC')->get();
        return view('addon.committee.frontend.candidate.index',$data);
    }

    public function dataFilter(Request $request){

        $data['committeeCandidate'] = CommitteeCandidate ::join('committee_designations', 'committee_candidates.committee_designation_id', 'committee_designations.id')
            ->join('users', 'committee_candidates.user_id', 'users.id')
            ->leftJoin('alumnus','committee_candidates.user_id','alumnus.id')
            ->select([
                'committee_candidates.*',
                'committee_designations.name as designationName',
                'users.name as userName',
                'committee_candidates.photo as userPhoto',
                'alumnus.company as companyName'
            ])
            ->where('committee_designations.tenant_id', getTenantId())
            ->where('committee_candidates.committee_election_id', $request->committee_election_id)
            ->where('committee_candidates.status', STATUS_ACTIVE)
            ->orderBy('committee_designations.order', 'ASC')
            ->paginate(8);

        $html = view('addon.committee.frontend.candidate.card', $data)->render();

        return $this->success(['html' => $html], __(DATA_FETCH_SUCCESSFULLY));
    }

    public function details($id){

        $data['title'] = __('Candidate Details');
        $data['candidateDetails'] =CommitteeCandidate::where('id', $id)
            ->where('tenant_id', getTenantId())
            ->with(['user', 'committee', 'election', 'position', 'nomination','alumnus'])
            ->first();

        $data['candidateCommentData'] = CommitteeCandidate::where('status', STATUS_ACTIVE)
            ->where('id',$id)
            ->where('tenant_id',getTenantId())
            ->with(['comments.replies.user', 'comments.user'])
            ->first();

        $totalComments = $data['candidateDetails']->comments->count();
        foreach ($data['candidateDetails']->comments as $comment) {
            $totalComments += $comment->replies->count();
        }
        $data['totalComment'] = $totalComments;


        $link = route('committee.candidate.details', $id);

        $data['fb_share'] = 'http://www.facebook.com/sharer/sharer.php?u='.$link;
        $data['tw_share'] = 'http://www.twitter.com/share?url='.$link;
        $data['link_share'] = 'https://www.linkedin.com/sharing/share-offsite/?url='.$link;
        $data['pinterest_share'] = 'https://www.pinterest.com/pin/create/button/?url='.$link;

        return view('addon.committee.frontend.candidate.details',$data);
    }

    public function comment($id, Request $request)
    {
        $request->validate([
            'comment' => 'bail|required|min:5',
        ]);

        try{
            CommitteeCandidateComment::create([
                'tenant_id' => getTenantId(),
                'user_id' => auth()->id(),
                'committee_candidate_id' => $id,
                'committee_candidate_comment_id' => $request->id,
                'comment' => $request->comment,
                'status' => STATUS_PENDING,
            ]);
        }catch (Exception $e){
            return redirect()->back()->with('error', __('Something is wrong! Try again.'));
        }
        return redirect()->back()->with('success', __('Commented Added Successfully. Please wait for review'));

    }
}
