<?php

namespace App\Http\Controllers\addon\committee\frontend;

use App\Http\Controllers\Controller;
use App\Models\Committee;
use App\Models\CommitteeCategory;
use App\Models\CommitteeDesignation;
use App\Models\CommitteeElection;
use App\Traits\ResponseTrait;
use Illuminate\Http\Request;


class CommitteeController extends Controller
{
    use ResponseTrait;

    public function index($categorySlug)
    {
        $data['title'] = __('Committee');
        $data['committeeCategory'] = CommitteeCategory::where('slug', $categorySlug)->where('tenant_id', getTenantId())->first();
        $data['designationData'] = CommitteeElection::where(['status' => STATUS_ACTIVE , 'tenant_id' => getTenantId()])->orderBy('id', 'DESC')->get();
        return view('addon.committee.frontend.committee', $data);
    }

    public function details($id)
    {
        $data['committeeDetails'] = Committee::join('committee_designations', 'committees.committee_designation_id', 'committee_designations.id')
            ->join('users', 'committees.user_id', 'users.id')
            ->join('alumnus', 'committees.user_id', 'alumnus.user_id')
            ->select([
                'committees.photo as image',
                'alumnus.company',
                'alumnus.address',
                'committee_designations.name as designationName',
                'committee_designations.order',
                'users.name as userName',
                'users.email as userEmail',
                'users.mobile as userMobile',
            ])
            ->where('committees.id', $id)
            ->first();

        return view('addon.committee.frontend.committee_details', $data);
    }

    public function dataFilter(Request $request){

        $data['committees'] = Committee::join('committee_designations', 'committees.committee_designation_id', 'committee_designations.id')
            ->join('committee_categories', 'committees.committee_category_id', 'committee_categories.id')
            ->join('users', 'committees.user_id', 'users.id')
            ->select([
                'committees.*',
                'committee_designations.name as designationName',
                'committee_designations.order',
                'users.name as userName',
                'users.email as userEmail',
                'users.mobile as userMobile',
            ])
            ->where('committees.tenant_id', getTenantId())
            ->where('committees.committee_election_id', $request->election_id)
            ->where('committee_categories.slug', $request->committee_category_slug)
            ->orderBy('committee_designations.order', 'ASC')
            ->paginate(8);

        $html = view('addon.committee.frontend.committee-card', $data)->render();

        return $this->success(['html' => $html], __(DATA_FETCH_SUCCESSFULLY));
    }


}
