<?php

namespace App\Http\Services\addon\committee;

use App\Models\CommitteeCandidateFlag;
use App\Models\FileManager;
use App\Traits\ResponseTrait;
use Exception;
use Illuminate\Support\Facades\DB;

class CandidateFlagService
{
    use ResponseTrait;

    public function list($request)
    {
        $candidateFlag = CommitteeCandidateFlag::
            join('committee_categories', 'committee_categories.id' , '=', 'committee_candidate_flags.committee_category_id')
            ->join('committee_elections', 'committee_elections.id' , '=', 'committee_candidate_flags.committee_election_id')
            ->select('committee_categories.name as categoryName', 'committee_elections.title as electionName','committee_candidate_flags.*')
            ->where('committee_candidate_flags.tenant_id', getTenantId())->orderBy('committee_candidate_flags.id','DESC');

        if($request->committee_election_id != 0){
            $candidateFlag->where('committee_category_id', $request->committee_election_id);
        }
        if($request->committee_category_id != 0){
            $candidateFlag->where('committee_election_id', $request->committee_category_id);
        }
        return datatables($candidateFlag)
            ->editColumn('flag', function ($data) {
                return '<img class="avatar-xs max-h-35 max-h-69 rounded" src="' . getFileUrl($data->flag) . '"/>';
            })
            ->editColumn('status' , function ($data){
                if ($data->status == STATUS_ACTIVE) {
                    return '<p class="d-inline-block py-6 px-10 bd-ra-6 fs-14 fw-500 lh-16 text-0fa958 bg-0fa958-10">'.__('Active').'</p>';
                } else {
                    return '<p class="d-inline-block py-6 px-10 bd-ra-6 fs-14 fw-500 lh-16 text-f5b40a bg-f5b40a-10">'.__('Deactivate').'</p>';
                }
            })
            ->addColumn('action', function ($data){
                return '<ul class="d-flex align-items-center cg-5 justify-content-center">
                            <li class="d-flex gap-2">
                                <button onclick="getEditModal(\'' . route('committee.admin.candidate-flag.edit', $data->id) . '\'' . ', \'#committee-candidate-flag-edit-modal\')" class="d-flex justify-content-center align-items-center w-30 h-30 rounded-circle bd-one bd-c-ededed bg-white" data-bs-toggle="modal" data-bs-target="#alumniPhoneNo" title="'.__('Edit').'">
                                    <img src="' . asset('assets/images/icon/edit.svg') . '" alt="edit" />
                                </button>
                                <button onclick="deleteItem(\'' . route('committee.admin.candidate-flag.delete', $data->id) . '\', \'committeeCandidateFlagDatatable\')" class="d-flex justify-content-center align-items-center w-30 h-30 rounded-circle bd-one bd-c-ededed bg-white" title="'.__('Delete').'">
                                    <img src="' . asset('assets/images/icon/delete-1.svg') . '" alt="delete">
                                </button>
                            </li>
                        </ul>';
            })
            ->rawColumns(['action', 'status','flag'])
            ->make(true);
    }


    public function store($request)
    {
        DB::beginTransaction();
        try {

            $candidateFlag = New CommitteeCandidateFlag();

            $photo = NULL;

            if ($request->hasFile('flag')) {
                $new_file = new FileManager();
                $uploaded = $new_file->upload('candidate', $request->flag);
                $flag = $uploaded->id;
            }

            $candidateFlag->tenant_id = getTenantId();
            $candidateFlag->name = $request->name;
            $candidateFlag->flag = $flag;
            $candidateFlag->committee_category_id = $request->committee_category_id;
            $candidateFlag->committee_election_id = $request->committee_election_id;
            $candidateFlag->status = $request->status;

            $candidateFlag->save();
            DB::commit();
            return $this->success([], getMessage(CREATED_SUCCESSFULLY));
        } catch (Exception $e) {
            DB::rollBack();
            return $this->error([], getMessage(SOMETHING_WENT_WRONG));
        }
    }

    public function update($id, $request)
    {
        DB::beginTransaction();
        try {
            $candidateFlag = CommitteeCandidateFlag::findOrfail($id);

            $flag = $candidateFlag->flag;

            if ($request->hasFile('flag')) {
                $new_file = new FileManager();
                $uploaded = $new_file->upload('candidate', $request->flag);
                $flag = $uploaded->id;
            }
            $candidateFlag->name = $request->name;
            $candidateFlag->flag = $flag;
            $candidateFlag->committee_category_id = $request->committee_category_id;
            $candidateFlag->committee_election_id = $request->committee_election_id;
            $candidateFlag->status = $request->status;

            $candidateFlag->save();
            DB::commit();
            $message = getMessage(UPDATED_SUCCESSFULLY);
            return $this->success([], $message);
        } catch (Exception $e) {
            DB::rollBack();
            $message = getErrorMessage($e, $e->getMessage());
            return $this->error([], $message);
        }
    }

    public function getById($id)
    {
        return CommitteeCandidateFlag::where('tenant_id', getTenantId())->findOrfail($id);
    }

    public function deleteById($id)
    {
        DB::beginTransaction();
        try {
            $candidateFlag = CommitteeCandidateFlag::FindOrFail($id);

            $candidateFlag->delete();
            DB::commit();
            $message = getMessage(DELETED_SUCCESSFULLY);
            return $this->success([], $message);
        } catch (\Exception $e) {
            DB::rollBack();
            $message = getErrorMessage($e, $e->getMessage());
            return $this->error([], $message);
        }
    }
    public function getAllActive($committee_election_id, $committee_category_id)
    {
        return CommitteeCandidateFlag::where('tenant_id', getTenantId())
            ->where(['status' => STATUS_ACTIVE, 'committee_election_id' => $committee_election_id, 'committee_category_id' => $committee_category_id])
            ->get();
    }

}
