<?php

namespace App\Http\Services\addon\committee;

use App\Models\CommitteeCandidate;
use App\Models\CommitteeNominationForm;
use App\Traits\ResponseTrait;

class CandidateService
{
    use ResponseTrait;

    public function getById($id)
    {
        return CommitteeCandidate::where('tenant_id', getTenantId())->where(['id' => $id])->first();
    }

    public function list($request, $status)
    {
        $nomination = CommitteeCandidate::where('committee_candidates.status', $status)
            ->where('committee_candidates.tenant_id', getTenantId())
            ->join('committee_designations', 'committee_designations.id', '=', 'committee_candidates.committee_designation_id')
            ->join('committee_elections', 'committee_elections.id', '=', 'committee_candidates.committee_election_id')
            ->join('committee_categories', 'committee_categories.id', '=', 'committee_candidates.committee_category_id')
            ->leftJoin('payments', 'payments.id', '=', 'committee_candidates.payment_id')
            ->where(function($query) {
                $query->whereNull('payments.id')
                ->orWhere('payments.payment_status', PAYMENT_STATUS_PAID);
            })
            ->select('committee_designations.name as designation', 'committee_categories.name as category', 'committee_elections.session', 'committee_candidates.*')
            ->with('user')
            ->orderBy('committee_elections.id', 'DESC');


        if ($request->committee_election_id != 0) {
            $nomination->where('committee_elections.id', $request->committee_election_id);
        }
        if ($request->committee_category_id != 0) {
            $nomination->where('committee_categories.id', $request->committee_category_id);
        }

        return datatables($nomination)
            ->editColumn('status', function ($data) {
                if ($data->status == STATUS_PENDING) {
                    return '<span class="zBadge">' . __("Pending") . '</span>';
                }

                return '<span class="zBadge-paid">' . __("Approved") . '</span>';
            })
            ->editColumn('photo', function ($data) {
                if(!is_null($data->photo)){
                    return '<img class="avatar-xs max-h-35 max-h-69 rounded" src="'.getFileUrl($data->photo) .'"/>';
                }

                return '<img class="avatar-xs max-h-35 max-h-69 rounded" src="'.getFileUrl($data->user->image) .'"/>';
            })
            ->editColumn('amount', function ($data) {
                if (!is_null($data->amount) && $data->amount > 0) {
                    return showPrice($data->amount);
                }
                return __('N/A');
            })
            ->addColumn('action', function ($data) use ($status){
                $route = ($status == 1) ? route('committee.candidate.details', [$data->id]) : route('committee.admin.candidates.view', $data->id);
                return '<ul class="d-flex align-items-center cg-5 justify-content-center">
                            <li class="d-flex gap-2">
                                <a href="'.$route.'" target="__blank" class="d-flex justify-content-center align-items-center w-30 h-30 rounded-circle bd-one bd-c-ededed bg-white" title="' . __('View') . '">
                                    <img src="' . asset('assets/images/icon/eye.svg') . '" alt="View" />
                                </a>
                            </li>
                        </ul>';
            })
            ->rawColumns(['action', 'status', 'photo'])
            ->make(true);
    }

    public function getData($id)
    {
        return CommitteeCandidate::where('id', $id)
            ->where('tenant_id', getTenantId())
            ->with(['user', 'committee', 'election', 'position', 'nomination'])
            ->first();
    }
}
