<?php

namespace App\Http\Services\addon\committee;

use App\Models\CommitteeDesignation;
use App\Traits\ResponseTrait;
use Exception;
use Illuminate\Support\Facades\DB;

class DesignationService
{
    use ResponseTrait;

    public function list()
    {
        $committeeDesignation = CommitteeDesignation::query()->where('tenant_id', getTenantId())->orderBy('order','ASC');
        return datatables($committeeDesignation)
            ->addIndexColumn()
            ->editColumn('status' , function ($data){
                if ($data->status == STATUS_ACTIVE) {
                    return '<p class="d-inline-block py-6 px-10 bd-ra-6 fs-14 fw-500 lh-16 text-0fa958 bg-0fa958-10">'.__('Active').'</p>';
                } else {
                    return '<p class="d-inline-block py-6 px-10 bd-ra-6 fs-14 fw-500 lh-16 text-f5b40a bg-f5b40a-10">'.__('Deactivate').'</p>';
                }
            })
            ->addColumn('action', function ($data){
                return '<ul class="d-flex align-items-center cg-5 justify-content-center">
                            <li class="d-flex gap-2">
                                <button onclick="getEditModal(\'' . route('committee.admin.designation.edit', $data->id) . '\'' . ', \'#committee-designation-edit-modal\')" class="d-flex justify-content-center align-items-center w-30 h-30 rounded-circle bd-one bd-c-ededed bg-white" data-bs-toggle="modal" data-bs-target="#alumniPhoneNo" title="'.__('Edit').'">
                                    <img src="' . asset('assets/images/icon/edit.svg') . '" alt="edit" />
                                </button>
                                <button onclick="deleteItem(\'' . route('committee.admin.designation.delete', $data->id) . '\', \'committeeDesignationDatatable\')" class="d-flex justify-content-center align-items-center w-30 h-30 rounded-circle bd-one bd-c-ededed bg-white" title="'.__('Delete').'">
                                    <img src="' . asset('assets/images/icon/delete-1.svg') . '" alt="delete">
                                </button>
                            </li>
                        </ul>';
            })
            ->rawColumns(['action', 'status'])
            ->make(true);
    }


    public function store($request)
    {
        DB::beginTransaction();
        try {

            $committeeDesignation = New CommitteeDesignation();

            $committeeDesignation->tenant_id = getTenantId();
            $committeeDesignation->name = $request->name;
            $committeeDesignation->order = $request->order;
            $committeeDesignation->status = $request->status;

            $committeeDesignation->save();
            DB::commit();
            return $this->success([], getMessage(CREATED_SUCCESSFULLY));
        } catch (Exception $e) {
            DB::rollBack();
            return $this->error([], getMessage(SOMETHING_WENT_WRONG));
        }
    }

    public function update($id, $request)
    {
        DB::beginTransaction();
        try {
            $committeeDesignation = CommitteeDesignation::findOrfail($id);

            $committeeDesignation->name = $request->name;
            $committeeDesignation->order = $request->order;
            $committeeDesignation->status = $request->status;

            $committeeDesignation->save();
            DB::commit();
            $message = getMessage(UPDATED_SUCCESSFULLY);
            return $this->success([], $message);
        } catch (Exception $e) {
            DB::rollBack();
            $message = getErrorMessage($e, $e->getMessage());
            return $this->error([], $message);
        }
    }

    public function getById($id)
    {
        return CommitteeDesignation::where('tenant_id', getTenantId())->findOrfail($id);
    }

    public function getAllActive()
    {
        return CommitteeDesignation::where('tenant_id', getTenantId())->where('status', STATUS_ACTIVE)->orderBy('order', 'ASC')->get();
    }

    public function deleteById($id)
    {
        DB::beginTransaction();
        try {
            $committeeDesignation = CommitteeDesignation::FindOrFail($id);

            $committeeDesignation->delete();
            DB::commit();
            $message = getMessage(DELETED_SUCCESSFULLY);
            return $this->success([], $message);
        } catch (\Exception $e) {
            DB::rollBack();
            $message = getErrorMessage($e, $e->getMessage());
            return $this->error([], $message);
        }
    }

}
