<?php

namespace App\Http\Services\addon\committee;

use App\Models\CommitteeElection;
use App\Traits\ResponseTrait;
use Exception;
use Illuminate\Support\Facades\DB;

class ElectionService
{
    use ResponseTrait;

    public function list()
    {
        $committeeElection = CommitteeElection::query()->where('tenant_id', getTenantId())->orderBy('id','DESC');
        return datatables($committeeElection)
            ->addIndexColumn()
            ->editColumn('status' , function ($data){
                if ($data->status == STATUS_ACTIVE) {
                    return '<p class="d-inline-block py-6 px-10 bd-ra-6 fs-14 fw-500 lh-16 text-0fa958 bg-0fa958-10">'.__('Active').'</p>';
                } else {
                    return '<p class="d-inline-block py-6 px-10 bd-ra-6 fs-14 fw-500 lh-16 text-f5b40a bg-f5b40a-10">'.__('Deactivate').'</p>';
                }
            })
            ->addColumn('action', function ($data){
                return '<ul class="d-flex align-items-center cg-5 justify-content-center">
                            <li class="d-flex gap-2">
                                <button onclick="getEditModal(\'' . route('committee.admin.election.edit', $data->id) . '\'' . ', \'#committee-election-edit-modal\')" class="d-flex justify-content-center align-items-center w-30 h-30 rounded-circle bd-one bd-c-ededed bg-white" data-bs-toggle="modal" data-bs-target="#alumniPhoneNo" title="'.__('Edit').'">
                                    <img src="' . asset('assets/images/icon/edit.svg') . '" alt="edit" />
                                </button>
                                <button onclick="deleteItem(\'' . route('committee.admin.election.delete', $data->id) . '\', \'committeeElectionDatatable\')" class="d-flex justify-content-center align-items-center w-30 h-30 rounded-circle bd-one bd-c-ededed bg-white" title="'.__('Delete').'">
                                    <img src="' . asset('assets/images/icon/delete-1.svg') . '" alt="delete">
                                </button>
                            </li>
                        </ul>';
            })
            ->rawColumns(['action', 'status'])
            ->make(true);
    }

    public function store($request)
    {
        DB::beginTransaction();
        try {

            $committeeElection = New CommitteeElection();

            $committeeElection->tenant_id = getTenantId();
            $committeeElection->title = $request->title;
            $committeeElection->session = $request->session;
            $committeeElection->vote_start_date = $request->vote_start_date;
            $committeeElection->vote_end_date = $request->vote_end_date;
            $committeeElection->details = $request->details;
            $committeeElection->status = $request->status;

            $committeeElection->save();
            DB::commit();
            return $this->success([], getMessage(CREATED_SUCCESSFULLY));
        } catch (Exception $e) {
            DB::rollBack();
            return $this->error([], getMessage(SOMETHING_WENT_WRONG));
        }
    }

    public function update($id, $request)
    {
        DB::beginTransaction();
        try {
            $committeeElection = CommitteeElection::findOrfail($id);

            $committeeElection->title = $request->title;
            $committeeElection->session = $request->session;
            $committeeElection->details = $request->details;
            $committeeElection->vote_start_date = $request->vote_start_date;
            $committeeElection->vote_end_date = $request->vote_end_date;
            $committeeElection->status = $request->status;

            $committeeElection->save();
            DB::commit();
            $message = getMessage(UPDATED_SUCCESSFULLY);
            return $this->success([], $message);
        } catch (Exception $e) {
            DB::rollBack();
            $message = getErrorMessage($e, $e->getMessage());
            return $this->error([], $message);
        }
    }

    public function getById($id)
    {
        return CommitteeElection::where('tenant_id', getTenantId())->findOrfail($id);
    }

    public function deleteById($id)
    {
        DB::beginTransaction();
        try {
            $committeeElection = CommitteeElection::FindOrFail($id);

            $committeeElection->delete();
            DB::commit();
            $message = getMessage(DELETED_SUCCESSFULLY);
            return $this->success([], $message);
        } catch (\Exception $e) {
            DB::rollBack();
            $message = getErrorMessage($e, $e->getMessage());
            return $this->error([], $message);
        }
    }
    public function getAllActive()
    {
        return CommitteeElection::where('tenant_id', getTenantId())->where('status', STATUS_ACTIVE)->get();
    }

    public function resultList()
    {
        $committeeElection = CommitteeElection::query()->where('tenant_id', getTenantId())->orderBy('id','DESC');
        return datatables($committeeElection)
            ->addIndexColumn()
            ->editColumn('status' , function ($data){
                if ($data->is_result_done == STATUS_ACTIVE) {
                    return '<p class="d-inline-block py-6 px-10 bd-ra-6 fs-14 fw-500 lh-16 text-0fa958 bg-0fa958-10">'.__('Published').'</p>';
                } else {
                    return '<p class="d-inline-block py-6 px-10 bd-ra-6 fs-14 fw-500 lh-16 text-f5b40a bg-f5b40a-10">'.__('N/A').'</p>';
                }
            })
            ->addColumn('action', function ($data){
                return '<ul class="d-flex align-items-center cg-5 justify-content-center">
                            <li class="d-flex gap-2">
                                <a href="'.route('committee.admin.election.results', $data->id).'" class="d-flex justify-content-center align-items-center w-30 h-30 rounded-circle bd-one bd-c-ededed bg-white" title="'.__('Result').'">
                                    <img src="' . asset('assets/images/icon/eye.svg') . '" alt="Result" />
                                </a>
                            </li>
                        </ul>';
            })
            ->rawColumns(['action', 'status'])
            ->make(true);
    }

}
