<?php

namespace App\Http\Services\addon\committee;

use App\Models\CommitteeElection;
use App\Models\CommitteeNominationForm;
use App\Models\CommitteeVote;
use App\Traits\ResponseTrait;
use Exception;
use Illuminate\Support\Facades\DB;

class VoteService
{
    use ResponseTrait;

    public function list($request)
    {
        $votes = CommitteeElection::where('committee_elections.tenant_id', getTenantId())
            ->where('committee_elections.vote_start_date', "<=", now())
            ->where('committee_elections.vote_end_date', ">=", now())
            ->where('committee_elections.status', STATUS_ACTIVE)
            ->orderBy('committee_elections.id', 'DESC');

        return datatables($votes)
            ->editColumn('status', function ($data) {
                return '<p class="d-inline-block py-6 px-10 bd-ra-6 fs-14 fw-500 lh-16 text-0fa958 bg-0fa958-10">' . __('Running') . '</p>';
            })
            ->addColumn('action', function ($data) {
                return '<ul class="d-flex align-items-center cg-5 justify-content-center" xmlns="http://www.w3.org/1999/html">
                            <li class="d-flex gap-2">
                                <a href="' . route('committee.alumni.votes.ballot', $data->id) . '" class="d-flex justify-content-center align-items-center w-30 h-30 rounded-circle bd-one bd-c-ededed bg-white" title="' . __('Apply') . '">
                                    <i class="fa-solid fa-long-arrow-right" /></i>
                                </a>
                            </li>
                        </ul>';
            })
            ->rawColumns(['action', 'status'])
            ->make(true);
    }

    public function voteList($request)
    {
        $votes = CommitteeVote::where('committee_votes.tenant_id', getTenantId())
            ->join('committee_designations', 'committee_designations.id', '=', 'committee_votes.committee_designation_id')
            ->join('committee_elections', 'committee_elections.id', '=', 'committee_votes.committee_election_id')
            ->join('committee_categories', 'committee_categories.id', '=', 'committee_votes.committee_category_id')
            ->leftJoin('committee_candidates', 'committee_candidates.id', '=', 'committee_votes.committee_candidate_id')
            ->leftJoin('users', 'users.id', '=', 'committee_candidates.user_id')
            ->select('committee_designations.name as designation', 'users.name as candidate_name', 'committee_categories.name as category', 'committee_elections.session', 'committee_votes.*')
            ->orderBy('committee_votes.id', 'DESC');

        if($request->committee_election_id != 0){
            $votes->where('committee_elections.id', $request->committee_election_id);
        }
        if($request->committee_category_id != 0){
            $votes->where('committee_categories.id', $request->committee_category_id);
        }
        if($request->committee_designation_id != 0){
            $votes->where('committee_designations.id', $request->committee_designation_id);
        }

        return datatables($votes)
            ->addIndexColumn()
            ->editColumn('status', function ($data) {
                if($data->status == STATUS_ACTIVE){
                    return '<p class="zBadge-paid">' . __('Approved') . '</p>';
                }
                return '<p class="zBadge-free">' . __('Rejected') . '</p>';
            })
            ->addColumn('vote_for', function ($data) {
                if(is_null($data->committee_candidate_id)){
                    return __('No Vote');
                }
                return $data->candidate_name;
            })
            ->addColumn('action', function ($data) {
                $html = '<div class="d-flex justify-content-center align-items-center g-10">';
                $html .= "<button type='button' class='border-0 p-0 bg-transparent flex-shrink-0 me-2 statusChange' title='Status Change' data-status='$data->status' data-id='$data->id'><img src='" . asset('assets/images/icon/edit.svg') . "'></button>";
                return $html;
            })
            ->rawColumns(['action', 'status'])
            ->make(true);
    }


    public function vote($request, $id)
    {
        DB::beginTransaction();
        try {
            $nominations = CommitteeNominationForm::where(['tenant_id' => getTenantId(), 'committee_election_id' => $id, 'status' => STATUS_ACTIVE])
                ->with(['final_candidates.user.alumni', 'position'])
                ->get();
            $voteCandidate = $request->candidate_id ?? [];
            foreach ($nominations as $nomination) {
                $candidate_id = !array_key_exists($nomination->id, $voteCandidate) ? NULL : $voteCandidate[$nomination->id];
                CommitteeVote::create([
                    'tenant_id' => getTenantId(),
                    'committee_election_id' => $nomination->committee_election_id,
                    'committee_category_id' => $nomination->committee_category_id,
                    'committee_designation_id' => $nomination->committee_designation_id,
                    'committee_candidate_id' => $candidate_id,
                    'user_id' => auth()->id(),
                    'status' => STATUS_ACTIVE,
                ]);
            }

            DB::commit();
            return $this->success(['url' => route('committee.alumni.votes.list', $id)], __('Successfully Saved'));
        } catch (Exception $e) {
            DB::rollBack();
            return $this->error([], __(SOMETHING_WENT_WRONG));
        }
    }

}
